@@ -1,7 +1,11 @@
 from .exception import PipelineError
 from .message import Message
 from .tap import DestinationTap, SourceTap, SourceOf, DestinationOf
-from .worker import Generator, Processor, Splitter
+from .worker import (
+    GeneratorConfig, Generator,
+    ProcessorConfig, Processor,
+    SplitterConfig, Splitter,
+)
 from .data import DataReaderOf, DataWriterOf
 from .utils import parse_kind
 
@@ -12,8 +16,11 @@ __all__ = [
     'DestinationOf',
     'SourceTap',
     'DestinationTap',
+    'GeneratorConfig',
     'Generator',
+    'ProcessorConfig',
     'Processor',
+    'SplitterConfig',
     'Splitter',
     'Message',
     'parse_kind',
